@@ -3,24 +3,17 @@ use utf8;
 use strict;
 use warnings FATAL => 'all';
 
-use Muldis::DB;
+use Muldis::DB::Interface;
 
 ###########################################################################
 ###########################################################################
 
 { package Muldis::DB::Validator; # module
-    our $VERSION = 0.001000;
+    our $VERSION = 0.002000;
 
     use Test::More;
 
-    use Muldis::DB::AST qw(newBoolLit newOrderLit newIntLit newBlobLit
-        newTextLit newTupleSel newQuasiTupleSel newRelationSel
-        newQuasiRelationSel newDefault newTreat newVarInvo newFuncInvo
-        newProcInvo newFuncReturn newProcReturn newEntityName newTypeInvoNQ
-        newTypeInvoAQ newTypeDictNQ newTypeDictAQ newExprDict newFuncDecl
-        newProcDecl newHostGateRtn newSetSel newQuasiSetSel newMaybeSel
-        newQuasiMaybeSel newSeqSel newQuasiSeqSel newBagSel
-        newQuasiBagSel);
+    use Muldis::DB::Literal qw(newQuasiSet);
 
 ###########################################################################
 
@@ -35,7 +28,7 @@ sub main {
         "#### Muldis::DB::Validator starting test of $engine_name ####\n";
 
     # Instantiate a Muldis::DB DBMS / virtual machine.
-    my $dbms = Muldis::DB::new_dbms({
+    my $dbms = Muldis::DB::Interface::new_dbms({
         'engine_name' => $engine_name, 'dbms_config' => $dbms_config });
     isa_ok( $dbms, 'Muldis::DB::Interface::DBMS' );
 
@@ -54,79 +47,79 @@ sub _scenario_foods_suppliers_shipments {
 
     # Declare our example executable code as Muldis::DB ASTs.
 
-    my $tynm_Text = newEntityName({ 'text' => 'sys.type.Text' });
-    my $tynm_UInt = newEntityName({ 'text' => 'sys.type.UInt' });
+    my $tynm_Text = Muldis::DB::Literal::EntityName->new({ 'text' => 'sys.type.Text' });
+    my $tynm_UInt = Muldis::DB::Literal::EntityName->new({ 'text' => 'sys.type.UInt' });
 
-    my $atnm_colour  = newEntityName({ 'text' => 'colour' });
-    my $atnm_country = newEntityName({ 'text' => 'country' });
-    my $atnm_farm    = newEntityName({ 'text' => 'farm' });
-    my $atnm_food    = newEntityName({ 'text' => 'food' });
-    my $atnm_qty     = newEntityName({ 'text' => 'qty' });
+    my $atnm_colour  = Muldis::DB::Literal::EntityName->new({ 'text' => 'colour' });
+    my $atnm_country = Muldis::DB::Literal::EntityName->new({ 'text' => 'country' });
+    my $atnm_farm    = Muldis::DB::Literal::EntityName->new({ 'text' => 'farm' });
+    my $atnm_food    = Muldis::DB::Literal::EntityName->new({ 'text' => 'food' });
+    my $atnm_qty     = Muldis::DB::Literal::EntityName->new({ 'text' => 'qty' });
 
     my $sca_type_Text
-        = newTypeInvoNQ({ 'kind' => 'Scalar', 'spec' => $tynm_Text });
+        = Muldis::DB::Literal::TypeInvo->new({ 'kind' => 'Scalar', 'spec' => $tynm_Text });
     my $sca_type_UInt
-        = newTypeInvoNQ({ 'kind' => 'Scalar', 'spec' => $tynm_UInt });
+        = Muldis::DB::Literal::TypeInvo->new({ 'kind' => 'Scalar', 'spec' => $tynm_UInt });
 
     my $qrel_type_Relation
-        = newTypeInvoAQ({ 'kind' => 'Any', 'spec' => 'Relation' });
+        = Muldis::DB::Literal::QuasiTypeInvo->new({ 'kind' => 'Any', 'spec' => 'Relation' });
 
-    my $heading_suppliers = newTypeDictNQ({ 'map' => [
+    my $heading_suppliers = Muldis::DB::Literal::TypeDict->new({ 'map' => [
         [$atnm_farm,    $sca_type_Text],
         [$atnm_country, $sca_type_Text],
     ] });
-    my $heading_foods = newTypeDictNQ({ 'map' => [
+    my $heading_foods = Muldis::DB::Literal::TypeDict->new({ 'map' => [
         [$atnm_food,   $sca_type_Text],
         [$atnm_colour, $sca_type_Text],
     ] });
-    my $heading_shipments = newTypeDictNQ({ 'map' => [
+    my $heading_shipments = Muldis::DB::Literal::TypeDict->new({ 'map' => [
         [$atnm_farm, $sca_type_Text],
         [$atnm_food, $sca_type_Text],
         [$atnm_qty,  $sca_type_UInt],
     ] });
-    my $heading_colours = newTypeDictNQ({ 'map' => [
+    my $heading_colours = Muldis::DB::Literal::TypeDict->new({ 'map' => [
         [$atnm_colour, $sca_type_Text],
     ] });
 
-    my $rel_type_suppliers = newTypeInvoNQ({
+    my $rel_type_suppliers = Muldis::DB::Literal::TypeInvo->new({
         'kind' => 'Relation', 'spec' => $heading_suppliers });
-    my $rel_type_foods = newTypeInvoNQ({
+    my $rel_type_foods = Muldis::DB::Literal::TypeInvo->new({
         'kind' => 'Relation', 'spec' => $heading_foods });
-    my $rel_type_shipments = newTypeInvoNQ({
+    my $rel_type_shipments = Muldis::DB::Literal::TypeInvo->new({
         'kind' => 'Relation', 'spec' => $heading_shipments });
 
-    my $pnm_matched_suppl = newEntityName({ 'text' => 'matched_supp' });
-    my $pnm_desi_colour   = newEntityName({ 'text' => 'desi_colour' });
-    my $pnm_src_suppl     = newEntityName({ 'text' => 'src_suppl' });
-    my $pnm_src_foods     = newEntityName({ 'text' => 'src_foods' });
-    my $pnm_src_shipm     = newEntityName({ 'text' => 'src_shipm' });
+    my $pnm_matched_suppl = Muldis::DB::Literal::EntityName->new({ 'text' => 'matched_supp' });
+    my $pnm_desi_colour   = Muldis::DB::Literal::EntityName->new({ 'text' => 'desi_colour' });
+    my $pnm_src_suppl     = Muldis::DB::Literal::EntityName->new({ 'text' => 'src_suppl' });
+    my $pnm_src_foods     = Muldis::DB::Literal::EntityName->new({ 'text' => 'src_foods' });
+    my $pnm_src_shipm     = Muldis::DB::Literal::EntityName->new({ 'text' => 'src_shipm' });
 
-    my $opnm_rel_asn = newEntityName({
+    my $opnm_rel_asn = Muldis::DB::Literal::EntityName->new({
         'text' => 'sys.rtn.Relation.assign' });
-    my $opnm_rel_jn  = newEntityName({
+    my $opnm_rel_jn  = Muldis::DB::Literal::EntityName->new({
         'text' => 'sys.rtn.Relation.join' });
-    my $opnm_rel_sjn = newEntityName({
+    my $opnm_rel_sjn = Muldis::DB::Literal::EntityName->new({
         'text' => 'sys.rtn.Relation.semijoin' });
 
-    my $anm_filter  = newEntityName({ 'text' => 'filter' });
-    my $anm_source  = newEntityName({ 'text' => 'source' });
-    my $anm_sources = newEntityName({ 'text' => 'sources' });
-    my $anm_target  = newEntityName({ 'text' => 'target' });
-    my $anm_v       = newEntityName({ 'text' => 'v' });
+    my $anm_filter  = Muldis::DB::Literal::EntityName->new({ 'text' => 'filter' });
+    my $anm_source  = Muldis::DB::Literal::EntityName->new({ 'text' => 'source' });
+    my $anm_sources = Muldis::DB::Literal::EntityName->new({ 'text' => 'sources' });
+    my $anm_target  = Muldis::DB::Literal::EntityName->new({ 'text' => 'target' });
+    my $anm_v       = Muldis::DB::Literal::EntityName->new({ 'text' => 'v' });
 
-    my $expr_3jn_ssp_sfd_scl = newFuncInvo({
+    my $expr_3jn_ssp_sfd_scl = Muldis::DB::Literal::FuncInvo->new({
         'func' => $opnm_rel_jn,
-        'ro_args' => newExprDict({ 'map' => [
-            [$anm_sources, newQuasiSetSel({
+        'ro_args' => Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+            [$anm_sources, newQuasiSet({
                 'heading' => $qrel_type_Relation,
                 'body' => [
-                    newVarInvo({ 'v' => $pnm_src_shipm }),
-                    newVarInvo({ 'v' => $pnm_src_foods }),
-                    newRelationSel({
+                    Muldis::DB::Literal::VarInvo->new({ 'v' => $pnm_src_shipm }),
+                    Muldis::DB::Literal::VarInvo->new({ 'v' => $pnm_src_foods }),
+                    Muldis::DB::Literal::Relation->new({
                         'heading' => $heading_colours,
                         'body' => [
-                            newExprDict({ 'map' => [
-                                [$atnm_colour, newVarInvo({
+                            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                                [$atnm_colour, Muldis::DB::Literal::VarInvo->new({
                                     'v' => $pnm_desi_colour })],
                             ] }),
                         ],
@@ -136,36 +129,36 @@ sub _scenario_foods_suppliers_shipments {
         ] }),
     });
 
-    my $query_suppl_of_foods_of_clr = newHostGateRtn({
-        'upd_params' => newTypeDictNQ({ 'map' => [
+    my $query_suppl_of_foods_of_clr = Muldis::DB::Literal::HostGateRtn->new({
+        'upd_params' => Muldis::DB::Literal::TypeDict->new({ 'map' => [
             [$pnm_matched_suppl, $rel_type_suppliers],
         ] }),
-        'ro_params' => newTypeDictNQ({ 'map' => [
+        'ro_params' => Muldis::DB::Literal::TypeDict->new({ 'map' => [
             [$pnm_desi_colour, $sca_type_Text],
             [$pnm_src_suppl,   $rel_type_suppliers],
             [$pnm_src_foods,   $rel_type_foods],
             [$pnm_src_shipm,   $rel_type_shipments],
         ] }),
-        'vars' => newTypeDictNQ({ 'map' => [] }),
+        'vars' => Muldis::DB::Literal::TypeDict->new({ 'map' => [] }),
         'stmts' => [
-            newProcInvo({
+            Muldis::DB::Literal::ProcInvo->new({
                 'proc' => $opnm_rel_asn,
-                'upd_args' => newExprDict({ 'map' => [
-                    [$anm_target, newVarInvo({
+                'upd_args' => Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                    [$anm_target, Muldis::DB::Literal::VarInvo->new({
                         'v' => $pnm_matched_suppl})],
                 ] }),
-                'ro_args' => newExprDict({ 'map' => [
-                    [$anm_v, newFuncInvo({
+                'ro_args' => Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                    [$anm_v, Muldis::DB::Literal::FuncInvo->new({
                         'func' => $opnm_rel_sjn,
-                        'ro_args' => newExprDict({ 'map' => [
-                            [$anm_source, newVarInvo({
+                        'ro_args' => Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                            [$anm_source, Muldis::DB::Literal::VarInvo->new({
                                 'v' => $pnm_src_suppl })],
                             [$anm_filter, $expr_3jn_ssp_sfd_scl],
                         ] }),
                     })],
                 ] }),
             }),
-            newProcReturn(),
+            Muldis::DB::Literal::ProcReturn->new(),
         ],
     });
 
@@ -206,87 +199,87 @@ sub _scenario_foods_suppliers_shipments {
 
     # Declare our example literal source data sets as Muldis::DB ASTs.
 
-    my $rel_def_suppliers = newRelationSel({
+    my $rel_def_suppliers = Muldis::DB::Literal::Relation->new({
         'heading' => $heading_suppliers,
         'body' => [
-            newExprDict({ 'map' => [
-                [$atnm_farm,    newTextLit({ 'v' => 'Hodgesons' })],
-                [$atnm_country, newTextLit({ 'v' => 'Canada' })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm,    Muldis::DB::Literal::Text->new({ 'v' => 'Hodgesons' })],
+                [$atnm_country, Muldis::DB::Literal::Text->new({ 'v' => 'Canada' })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_farm,    newTextLit({ 'v' => 'Beckers' })],
-                [$atnm_country, newTextLit({ 'v' => 'England' })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm,    Muldis::DB::Literal::Text->new({ 'v' => 'Beckers' })],
+                [$atnm_country, Muldis::DB::Literal::Text->new({ 'v' => 'England' })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_farm,    newTextLit({ 'v' => 'Wickets' })],
-                [$atnm_country, newTextLit({ 'v' => 'Canada' })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm,    Muldis::DB::Literal::Text->new({ 'v' => 'Wickets' })],
+                [$atnm_country, Muldis::DB::Literal::Text->new({ 'v' => 'Canada' })],
             ] }),
         ],
     });
 
-    my $rel_def_foods = newRelationSel({
+    my $rel_def_foods = Muldis::DB::Literal::Relation->new({
         'heading' => $heading_foods,
         'body' => [
-            newExprDict({ 'map' => [
-                [$atnm_food,   newTextLit({ 'v' => 'Bananas' })],
-                [$atnm_colour, newTextLit({ 'v' => 'yellow' })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_food,   Muldis::DB::Literal::Text->new({ 'v' => 'Bananas' })],
+                [$atnm_colour, Muldis::DB::Literal::Text->new({ 'v' => 'yellow' })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_food,   newTextLit({ 'v' => 'Carrots' })],
-                [$atnm_colour, newTextLit({ 'v' => 'orange' })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_food,   Muldis::DB::Literal::Text->new({ 'v' => 'Carrots' })],
+                [$atnm_colour, Muldis::DB::Literal::Text->new({ 'v' => 'orange' })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_food,   newTextLit({ 'v' => 'Oranges' })],
-                [$atnm_colour, newTextLit({ 'v' => 'orange' })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_food,   Muldis::DB::Literal::Text->new({ 'v' => 'Oranges' })],
+                [$atnm_colour, Muldis::DB::Literal::Text->new({ 'v' => 'orange' })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_food,   newTextLit({ 'v' => 'Kiwis' })],
-                [$atnm_colour, newTextLit({ 'v' => 'green' })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_food,   Muldis::DB::Literal::Text->new({ 'v' => 'Kiwis' })],
+                [$atnm_colour, Muldis::DB::Literal::Text->new({ 'v' => 'green' })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_food,   newTextLit({ 'v' => 'Lemons' })],
-                [$atnm_colour, newTextLit({ 'v' => 'yellow' })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_food,   Muldis::DB::Literal::Text->new({ 'v' => 'Lemons' })],
+                [$atnm_colour, Muldis::DB::Literal::Text->new({ 'v' => 'yellow' })],
             ] }),
         ],
     });
 
-    my $rel_def_shipments = newRelationSel({
+    my $rel_def_shipments = Muldis::DB::Literal::Relation->new({
         'heading' => $heading_shipments,
         'body' => [
-            newExprDict({ 'map' => [
-                [$atnm_farm, newTextLit({ 'v' => 'Hodgesons' })],
-                [$atnm_food, newTextLit({ 'v' => 'Kiwis' })],
-                [$atnm_qty,  newIntLit({ 'v' => 100 })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm, Muldis::DB::Literal::Text->new({ 'v' => 'Hodgesons' })],
+                [$atnm_food, Muldis::DB::Literal::Text->new({ 'v' => 'Kiwis' })],
+                [$atnm_qty,  Muldis::DB::Literal::Int->new({ 'v' => 100 })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_farm, newTextLit({ 'v' => 'Hodgesons' })],
-                [$atnm_food, newTextLit({ 'v' => 'Lemons' })],
-                [$atnm_qty,  newIntLit({ 'v' => 130 })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm, Muldis::DB::Literal::Text->new({ 'v' => 'Hodgesons' })],
+                [$atnm_food, Muldis::DB::Literal::Text->new({ 'v' => 'Lemons' })],
+                [$atnm_qty,  Muldis::DB::Literal::Int->new({ 'v' => 130 })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_farm, newTextLit({ 'v' => 'Hodgesons' })],
-                [$atnm_food, newTextLit({ 'v' => 'Oranges' })],
-                [$atnm_qty,  newIntLit({ 'v' => 10 })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm, Muldis::DB::Literal::Text->new({ 'v' => 'Hodgesons' })],
+                [$atnm_food, Muldis::DB::Literal::Text->new({ 'v' => 'Oranges' })],
+                [$atnm_qty,  Muldis::DB::Literal::Int->new({ 'v' => 10 })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_farm, newTextLit({ 'v' => 'Hodgesons' })],
-                [$atnm_food, newTextLit({ 'v' => 'Carrots' })],
-                [$atnm_qty,  newIntLit({ 'v' => 50 })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm, Muldis::DB::Literal::Text->new({ 'v' => 'Hodgesons' })],
+                [$atnm_food, Muldis::DB::Literal::Text->new({ 'v' => 'Carrots' })],
+                [$atnm_qty,  Muldis::DB::Literal::Int->new({ 'v' => 50 })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_farm, newTextLit({ 'v' => 'Beckers' })],
-                [$atnm_food, newTextLit({ 'v' => 'Carrots' })],
-                [$atnm_qty,  newIntLit({ 'v' => 90 })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm, Muldis::DB::Literal::Text->new({ 'v' => 'Beckers' })],
+                [$atnm_food, Muldis::DB::Literal::Text->new({ 'v' => 'Carrots' })],
+                [$atnm_qty,  Muldis::DB::Literal::Int->new({ 'v' => 90 })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_farm, newTextLit({ 'v' => 'Beckers' })],
-                [$atnm_food, newTextLit({ 'v' => 'Bananas' })],
-                [$atnm_qty,  newIntLit({ 'v' => 120 })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm, Muldis::DB::Literal::Text->new({ 'v' => 'Beckers' })],
+                [$atnm_food, Muldis::DB::Literal::Text->new({ 'v' => 'Bananas' })],
+                [$atnm_qty,  Muldis::DB::Literal::Int->new({ 'v' => 120 })],
             ] }),
-            newExprDict({ 'map' => [
-                [$atnm_farm, newTextLit({ 'v' => 'Wickets' })],
-                [$atnm_food, newTextLit({ 'v' => 'Lemons' })],
-                [$atnm_qty,  newIntLit({ 'v' => 30 })],
+            Muldis::DB::Literal::_ExprDict->new({ 'map' => [
+                [$atnm_farm, Muldis::DB::Literal::Text->new({ 'v' => 'Wickets' })],
+                [$atnm_food, Muldis::DB::Literal::Text->new({ 'v' => 'Lemons' })],
+                [$atnm_qty,  Muldis::DB::Literal::Int->new({ 'v' => 30 })],
             ] }),
         ],
     });
@@ -304,7 +297,7 @@ sub _scenario_foods_suppliers_shipments {
     # data and see what suppliers there are for foods coloured 'orange'.
 
     $desi_colour->store_ast({
-        'val_ast' => newTextLit({ 'v' => 'orange' }) });
+        'val_ast' => Muldis::DB::Literal::Text->new({ 'v' => 'orange' }) });
     pass( 'no death from loading desired colour into VM' );
 
     $prep_rtn_suppl_of_foods_of_clr->execute();
@@ -347,7 +340,7 @@ A common comprehensive test suite to run against all Engines
 
 =head1 VERSION
 
-This document describes Muldis::DB::Validator version 0.1.0 for Perl 5.
+This document describes Muldis::DB::Validator version 0.2.0 for Perl 5.
 
 =head1 SYNOPSIS
 
@@ -429,7 +422,7 @@ I<This documentation is pending.>
 This file requires any version of Perl 5.x.y that is at least 5.8.1.
 
 It also requires these Perl 5 classes that are in the current distribution:
-L<Muldis::DB::AST-(0.1.0)|Muldis::DB::AST>, L<Muldis::DB-0.1.0|Muldis::DB>.
+L<Muldis::DB::Literal-(0.2.0)|Muldis::DB::Literal>, L<Muldis::DB::Interface-0.2.0|Muldis::DB::Interface>.
 
 =head1 INCOMPATIBILITIES
 
